// Case for Raspbery Pi and WD Pi drive
// Print at .3 Layer height with 2 extra shells and 15% infill


BoxLen = 185;
BoxThk = 3;
BoxWid = 123;
BoxHgt = 70;
BoxCornerRad = 6;
BoxCornerLen = 8;  // Length of box from corner
BoxPanelInset = 2;
BoxPanelMntLen = 8;
BoxPanelSpacing = .5;
BoxFrontPanelLen = BoxLen - 2 * BoxCornerLen - 2 * BoxPanelSpacing;
BoxTopPanelLen = BoxWid -  2 * BoxCornerLen - 2 * BoxPanelSpacing;
BoxPanelHgt = BoxHgt - BoxThk - 1;
BoxPanelThk = 3;
LidMntIn = 5; // Inset of lid screws from corner

BracketMntIn = 92;  // Distance in from edge of box to first bracket mount hole
BracketMntDist = (HD2_HoleX2-HD2_HoleX1)-(2*(BracketWid-DriveMntHoleInset-TabScrewIn));

// USB socket mounts
M3ClearHole = 4;
USBsocketWid = 12;
USBsocketHgt = 21.5;
USBsocketBaseHgt = 38;
USBsocketBaseThk = 12;
USBsocketHoleSpacing = 30;
USBsocketInFront = 55;
USBsocketUpFront = BoxPanelHgt/2 - USBsocketHoleSpacing/2;
USBsocketVertSpacing = 14.5;
USBsocketInBack = 44;
USBsocketUpBack = 49;
USBsocketHorzSpacing = 39;

//Back of unit access holes
AudioHoleDia = 10.5;
HDMIwid = 19;
HDMIhgt = 9.5;
USBwid = 12;
USBhgt = 9;

// Ethernet Hole
EthernetWid = 16.75;
EthernetHgt = 15;
EthernetX = 45;
EthernetY = 10;

// Display stuff
DisplayUp = 11;
DisplayIn = 126;
DisplayMntWid = 5;
DisplayMntThk = 2;

// Switch stuff
SwitchUp = 15;
SwitchSpacing = 17;
NumSwitches = 4;
SwitchHoleDia = 4.2;
SwitchButtonDia = 3.4;
SwitchButtonHgt = 6;
SwitchWid = 6.2;
SwitchHgt = 3;

// LED stuff
LEDholeDia = 6.5;
LEDlen = 20;
LEDbezelDia = 7;
LEDbezelHgt = 3;
LEDdia = 5.5;
LEDup = 15;
LEDin = 10;
LEDspacing = 11;

// Fan stuff
FanWid = 40;
FanThk = 10;
FanHoleDia = 3.5;
FanClearHoleDia = 4;
FanHoleSpacing = 32;
FanUpFront = 50;
FanFrontHoleInset = (FanWid-FanHoleSpacing)/2;
FanOpeningDia = 38;
FanMntDia = 3.8;
FanBotIn = BoxPanelHgt-FanWid/2-3;
FanUpBot = 75;
FanSink = 1;  // Distance to sink fan into the bottom plate

// USB Serial stuff
USBserialConLen = 16.6;
USBserialConHgt = 10.75;
USBserialConWid = 12.3;
USBserialX = 29;
USBserialY = BoxWid - USBserialConLen - BoxPanelInset;

// Speakers
SpkDia = 29;
SpkHgt = 11;
SpkUp = 26;

// Feet
FootWid = 14;
FootLen = 17;
FootHgt = 8;
FootBaseLen = 12;
FootBaseWid = 11;

// Camera stuff
CamUp = 67;
CamHoleDia = 8.5;

// Lid stuff
WindowInset = 24;
WindowLip = 4;
WindowLipThk = 2;
WindowFrameGap = .25;

module doLogoJig()
{
	difference()
	{
		difference()
		{
			RndCube(BoxLen,BoxWid,WindowLipThk,BoxCornerRad);
			translate([WindowInset-WindowLip-.75/2,WindowInset-WindowLip-.75/2,-1])
				RndCube(BoxLen-2*WindowInset+WindowLip*2+.75,BoxWid-2*WindowInset+WindowLip*2+.75,4,BoxCornerRad);
			translate([(BoxLen-150)/2,5,-1])
				cube([150,10,5]);
			translate([(BoxLen-150)/2,BoxWid-15,-1])
				cube([150,10,5]);
			translate([5,(BoxWid-80)/2,-1])
				cube([10,80,5]);
			translate([BoxLen-15,(BoxWid-80)/2,-1])
				cube([10,80,5]);
		}
	}
}

module doLogo()
{
	difference()
	{
		translate([WindowInset-WindowLip,WindowInset-WindowLip,0])
			RndCube(BoxLen-2*WindowInset+WindowLip*2,BoxWid-2*WindowInset+WindowLip*2,WindowLipThk,BoxCornerRad);
			translate([WindowInset-WindowLip+(BoxLen-2*WindowInset+WindowLip*2)/2,WindowInset-WindowLip+(BoxWid-2*WindowInset+WindowLip*2)/2,0])
			translate([50,-39.5,0])
				linear_extrude(height = 10,center=true)
					scale([.5,.5,1])
						rotate([0,0,90])
						import(file="raspberrypi_logo.dxf",convexity=10);
	}
}

module doBoxTopPanel(Showing = 0)
{
	SwitchStart = BoxPanelHgt/(NumSwitches+1);
	difference()
	{
		union()
		{
			cube([BoxTopPanelLen,BoxPanelHgt,BoxPanelThk]);

			// Switch holders
			for(x=[1:NumSwitches])
				translate([SwitchUp,x*SwitchStart,BoxPanelThk+(SwitchHgt-1)/2])
					difference()
					{
						cube([SwitchWid+2,SwitchWid+2,SwitchHgt],center=true);
						cube([SwitchWid+.5,SwitchWid+.5,SwitchHgt+2],center=true);
					}
		}

		// Switch mounting holes
		for(x=[1:NumSwitches])
			translate([SwitchUp,x*SwitchStart,0])
				cylinder(d=SwitchHoleDia,h=12,$fn=36,center=true);

		// Panel mounting holes
		translate([BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxTopPanelLen-BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxTopPanelLen-BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxTopPanelLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxTopPanelLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);

		// Fan holes
		translate([FanUpBot,(BoxPanelHgt-FanWid)/2+FanWid/2,BoxPanelThk+.1])
			doBotFanHoles();
	}
	if (2 == Showing)
	{
		for(x=[1:NumSwitches])
			translate([SwitchUp,x*SwitchStart,BoxPanelThk+SwitchHgt])
				rotate([180,0,0])
					doSwitch();
	}
}

module doBoxBottomPanel(Showing = 0, Fan = 0, Feet = 0)
{
	union()
	{
		difference()
		{
			cube([BoxTopPanelLen,BoxPanelHgt,BoxThk]);  // No insert, same thinkness as box

			// Panel mounting holes
			translate([BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
				cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
			translate([BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
				cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
			translate([BoxTopPanelLen-BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
				cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
			translate([BoxTopPanelLen-BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
				cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
			translate([BoxTopPanelLen/2,BoxPanelMntLen/2,-1])
				cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
			translate([BoxTopPanelLen/2-BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1]) // Off center for fan clearance
				cylinder(d=Num2ClearHoleDia,h=6,$fn=8);

			// Fan holes
			if (Fan)
				translate([FanUpBot,FanBotIn,BoxPanelThk-FanSink])
					doBotFanHoles();
		}

		// Fan mounts
		if (Fan)
			translate([FanUpBot,FanBotIn,BoxPanelThk-FanSink])
				doFanMnts();
	}

	if (2 == Showing)
	{
		if (Fan)
			translate([FanUpBot,FanBotIn,BoxPanelThk-1])
				doFan();
	}

	if (Feet)
	{
		translate([0,FootWid-BoxThk,0])
			rotate([180,0,0])
				doFoot(1);
		translate([0,BoxPanelHgt+BoxThk,0])
			rotate([180,0,0])
				doFoot(0);
		translate([BoxTopPanelLen,BoxPanelHgt+BoxThk-FootWid,0])
			rotate([180,0,180])
				doFoot(1);
		translate([BoxTopPanelLen,-BoxThk,0])
			rotate([180,0,180])
				doFoot(0);
	}
}

module doBoxFrontPanel(Showing = 0)
{
	difference()
	{
		union()
		{
			cube([BoxFrontPanelLen,BoxPanelHgt,BoxPanelThk]);

			// Display mounts
			translate([BoxFrontPanelLen-(DisplayIn+DisplayMntWid/2),DisplayUp-DisplayMntWid/2,BoxPanelThk])
				cube([DisplayMntWid,DisplayMntWid,DisplayMntThk]);
			translate([BoxFrontPanelLen-(DisplayIn+DisplayMntWid/2+OLEDxSpacing),DisplayUp-DisplayMntWid/2,BoxPanelThk])
				cube([DisplayMntWid,DisplayMntWid,DisplayMntThk]);
			translate([BoxFrontPanelLen-(DisplayIn+DisplayMntWid/2),DisplayUp-DisplayMntWid/2+OLEDySpacing,BoxPanelThk])
				cube([DisplayMntWid,DisplayMntWid,DisplayMntThk]);
			translate([BoxFrontPanelLen-(DisplayIn+DisplayMntWid/2+OLEDxSpacing),DisplayUp-DisplayMntWid/2+OLEDySpacing,BoxPanelThk])
				cube([DisplayMntWid,DisplayMntWid,DisplayMntThk]);

			// Speaker boxes
			translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2+SpkDia/2+1.5,BoxPanelThk])
				difference()
				{
					cylinder(d=SpkDia+4,h=SpkHgt+2,$fn=72);
					cylinder(d=SpkDia+2,h=SpkHgt+3,$fn=72);
				}
			translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2-SpkDia/2-1.5,BoxPanelThk])
				difference()
				{
					cylinder(d=SpkDia+4,h=SpkHgt+2,$fn=72);
					cylinder(d=SpkDia+2,h=SpkHgt+3,$fn=72);
				}

			// Camera mounts
			translate([CamUp,BoxPanelHgt/2,BoxPanelThk])
				doCamMnts();
		}

		// Panel mounting holes
		translate([BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen-BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen-BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);

		// USB mounting holes
		translate([BoxFrontPanelLen-USBsocketInFront,USBsocketUpFront,0])
			doUSBholes();
//		translate([BoxFrontPanelLen-(USBsocketInFront+USBsocketVertSpacing),USBsocketUpFront,0])
//			doUSBholes();

		// Display mounting holes
		translate([BoxFrontPanelLen-DisplayIn,DisplayUp+OLEDxSpacing,BoxPanelThk+DisplayMntThk])
			rotate([180,0,270])
				doOLEDholes();

		// LED holes
		translate([LEDup,BoxPanelHgt-LEDin,0])
			cylinder(d=LEDholeDia,h=10,$fn=36,center=true);
		translate([LEDup+LEDspacing,BoxPanelHgt-LEDin,0])
			cylinder(d=LEDholeDia,h=10,$fn=36,center=true);
		translate([LEDup+2*LEDspacing,BoxPanelHgt-LEDin,0])
			cylinder(d=LEDholeDia,h=10,$fn=36,center=true);

		// Speaker holes
		translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2+SpkDia/2+1.5,-1])
			doSpeakerHoles();
		translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2-SpkDia/2-1.5,-1])
			doSpeakerHoles();

		// Camera holes
			translate([CamUp,BoxPanelHgt/2,1])
				doCamHoles();		
	}

	if (2 == Showing)
	{
		translate([BoxFrontPanelLen-DisplayIn,DisplayUp+OLEDxSpacing,BoxPanelThk+DisplayMntThk])
			rotate([180,0,270])
				doOLEDdisp();
		translate([BoxFrontPanelLen-USBsocketInFront,USBsocketUpFront,BoxPanelThk])
			doUSBsocket();
//		translate([BoxFrontPanelLen-(USBsocketInFront+USBsocketVertSpacing),USBsocketUpFront,BoxPanelThk])
//			doUSBsocket();
		translate([LEDup,BoxPanelHgt-LEDin,0])
			doLED(1);
		translate([LEDup+LEDspacing,BoxPanelHgt-LEDin,0])
			doLED(0);
		translate([LEDup+2*LEDspacing,BoxPanelHgt-LEDin,0])
			doLED(1);
		translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2+SpkDia/2+1.5,BoxPanelThk])
			doSpeaker();
		translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2-SpkDia/2-1.5,BoxPanelThk])
			doSpeaker();
		translate([BoxFrontPanelLen-SpkUp,BoxPanelHgt/2,BoxPanelThk+SpkHgt+2])
			doSpeakerLid();
	}
			
}

module doBoxBackPanel(Showing = 0)
{
	difference()
	{
		union()
		{
			// Back panel
			cube([BoxFrontPanelLen,BoxPanelHgt,BoxPanelThk]);

			// Ethernet holder
			translate([EthernetX,EthernetY,(6+BoxPanelThk)/2])
				cube([EthernetWid+5,EthernetHgt+4,6+BoxPanelThk],center=true);

			// Pi Hat support
			translate([BracketMntIn-BoxCornerLen+4,BracketHgt+PiMntHgt-BoxPanelSpacing+HatExtHeadThk+PiHeadThk-1.5,0])
				cube([52,7,5]);
		}

		// Panel mounting holes
		translate([BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen-BoxPanelMntLen/2,BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen-BoxPanelMntLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);
		translate([BoxFrontPanelLen/2,BoxPanelHgt-BoxPanelMntLen/2,-1])
			cylinder(d=Num2ClearHoleDia,h=6,$fn=8);

		// Back I/O holes
		translate([BracketMntIn-BoxCornerLen,BracketHgt+PiMntHgt-BoxPanelSpacing,0])
			doBackHoles();

		// Back bracket mount holes
		translate([BracketMntIn+TabScrewIn-SideMntWid/2-BoxCornerLen-BoxPanelSpacing,BracketHgt/2-BoxPanelSpacing,0])
			cylinder(d=Num2ClearHoleDia,h=15,center=true,$fn=8);
		translate([BracketMntIn+BracketMntDist-TabScrewIn+SideMntWid/2-BoxCornerLen-BoxPanelSpacing,BracketHgt/2-BoxPanelSpacing,0])
			cylinder(d=Num2ClearHoleDia,h=15,center=true,$fn=8);

		// Ethernet hole
		translate([EthernetX,EthernetY,4])
			cube([EthernetWid,EthernetHgt,12],center=true);

		// USB mounting holes
		translate([USBsocketInBack,USBsocketUpBack,0])
			rotate([0,0,90])
				doUSBholes();
		translate([USBsocketInBack+USBsocketHorzSpacing,USBsocketUpBack,0])
			rotate([0,0,90])
				doUSBholes();

		// USB Serial hole
		translate([USBserialX-BoxCornerLen-BoxPanelSpacing,-BoxPanelSpacing,-1])
			doUSBserialHole();

		// Audio cable hole
		translate([BoxFrontPanelLen/2+10,BoxPanelHgt-4,-1])
			cube([4,4.1,10]);

	}
	if (2 == Showing)
	{
		translate([EthernetX,EthernetY,0])
			doEthernet();
		// USB mounting holes
		translate([USBsocketInBack,USBsocketUpBack,BoxPanelThk])
			rotate([0,0,90])
				doUSBsocket();
		translate([USBsocketInBack+USBsocketHorzSpacing,USBsocketUpBack,BoxPanelThk])
			rotate([0,0,90])
				doUSBsocket();
	}
}

module doWindowFrame(Showing = 0)
{
	difference()
	{
		union()
		{
			translate([WindowInset-WindowLip,WindowInset-WindowLip,0])
				RndCube(BoxLen-2*WindowInset+WindowLip*2,BoxWid-2*WindowInset+WindowLip*2,WindowLipThk,BoxCornerRad);
			translate([WindowInset+WindowFrameGap,WindowInset+WindowFrameGap,WindowLipThk])
				RndCube(BoxLen-2*WindowInset-2*WindowFrameGap,BoxWid-2*WindowInset-2*WindowFrameGap,BoxThk+4,BoxCornerRad);
		}

		// Window openings
		translate([WindowInset+WindowFrameGap+2,WindowInset+WindowFrameGap+2,WindowLipThk])
			RndCube(BoxLen-2*WindowInset-2*WindowFrameGap-4,BoxWid-2*WindowInset-2*WindowFrameGap-4,BoxThk+5,BoxCornerRad);
		translate([WindowInset+WindowFrameGap+2+2,WindowInset+WindowFrameGap+2+2,-1])
			RndCube(BoxLen-2*WindowInset-2*WindowFrameGap-4-4,BoxWid-2*WindowInset-2*WindowFrameGap-4-4,WindowLipThk+2,BoxCornerRad);
	}
}

module doBoxSide(Showing = 0)
{
	difference()
	{
		union()
		{
			RndCube(BoxLen,BoxWid,BoxThk,BoxCornerRad);
			translate([WindowInset-2,WindowInset-2,0])
				RndCube(BoxLen-2*WindowInset+4,BoxWid-2*WindowInset+4,BoxThk+4,BoxCornerRad);

			// Mounting tabs
			translate([BoxPanelThk+BoxPanelInset,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2-BoxPanelMntLen/2,BoxThk])
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);
			translate([BoxLen-BoxPanelMntLen-BoxThk,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2-BoxPanelMntLen/2,BoxThk])
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);
			translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen/2-BoxPanelMntLen/2,BoxPanelThk+BoxPanelInset,BoxThk])
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);
			translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen/2-BoxPanelMntLen/2,BoxWid-BoxPanelMntLen-BoxPanelThk-BoxPanelInset,BoxThk])
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);
		}

		// Window opening
		translate([WindowInset,WindowInset,-1])
			RndCube(BoxLen-2*WindowInset,BoxWid-2*WindowInset,BoxThk+6,BoxCornerRad);

		// Do side mounting hoes
		translate([LidMntIn,LidMntIn,-1])
			cylinder(d=Num2ClearHoleDia,h=20,$fn=6);
		translate([BoxLen-LidMntIn,LidMntIn,-1])
			cylinder(d=Num2ClearHoleDia,h=20,$fn=6);
		translate([LidMntIn,BoxWid-LidMntIn,-1])
			cylinder(d=Num2ClearHoleDia,h=20,$fn=6);
		translate([BoxLen-LidMntIn,BoxWid-LidMntIn,-1])
			cylinder(d=Num2ClearHoleDia,h=20,$fn=6);
		translate([0,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxLen,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen/2,0,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen/2,8+BoxWid-BoxPanelMntLen-BoxPanelThk-BoxPanelInset,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
	}
}

module doBoxBase(Showing = 0)
{
	difference()
	{
		union()
		{
			difference()  // Main box
			{
				RndCube(BoxLen,BoxWid,BoxHgt,BoxCornerRad);

				// Do tabs for mounting panels
				translate([3*BoxThk+BoxPanelInset,3*BoxThk+BoxPanelInset,BoxThk]) // No inset on bottom panel
					cube([BoxLen-6*BoxThk-BoxPanelInset,BoxWid-6*BoxThk-2*BoxPanelInset,BoxHgt]);
				translate([BoxCornerLen+BoxPanelMntLen,-1,BoxThk])
					cube([BoxLen-2*BoxCornerLen-2*BoxPanelMntLen,15,BoxHgt]);
				translate([BoxCornerLen,BoxPanelInset+BoxPanelThk-10,BoxThk])
					cube([BoxLen-2*BoxCornerLen,10,BoxHgt]);
				translate([BoxCornerLen+BoxPanelMntLen,BoxWid-14,BoxThk])
					cube([BoxLen-2*BoxCornerLen-2*BoxPanelMntLen,15,BoxHgt]);
				translate([BoxCornerLen,BoxWid-(BoxPanelInset+BoxPanelThk),BoxThk])
					cube([BoxLen-2*BoxCornerLen,10,BoxHgt]);
				translate([-1,BoxCornerLen+BoxPanelMntLen,BoxThk])
					cube([15,BoxWid-2*BoxCornerLen-2*BoxPanelMntLen,BoxHgt]);
				translate([BoxPanelInset+BoxPanelThk-10,BoxCornerLen,BoxThk])
					cube([10,BoxWid-2*BoxCornerLen,BoxHgt]);
				translate([BoxLen-15,BoxCornerLen+BoxPanelMntLen,BoxThk])  // No inset on bottom
					cube([15,BoxWid-2*BoxCornerLen-2*BoxPanelMntLen,BoxHgt]);
				translate([BoxLen-BoxThk,BoxCornerLen,BoxThk])
					cube([10,BoxWid-2*BoxCornerLen,BoxHgt]);
			}


			// Bracket mounting tabs
			translate([BracketMntIn-(BracketTabLen-2)/2,BracketToSide-BracketTabWid/2-TabScrewOut,BoxThk])
				cube([BracketTabLen-2,BracketTabWid,BracketTabHgt]);
			translate([BracketMntIn-(BracketTabLen-2)/2+BracketMntDist,BracketToSide-BracketTabWid/2-TabScrewOut,BoxThk])
				cube([BracketTabLen-2,BracketTabWid,BracketTabHgt]);

			// Panel mounting tabs
			translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen/2-BoxPanelMntLen/2,BoxPanelThk+BoxPanelInset,BoxThk])
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);
			translate([BoxPanelThk+BoxPanelInset,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2-BoxPanelMntLen/2,BoxThk])
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);
			translate([BoxLen-BoxPanelMntLen-BoxThk,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2-BoxPanelMntLen,BoxThk]) // Off center for fan clearance
				cube([BoxPanelMntLen,BoxPanelMntLen,BoxPanelMntLen]);

			// USB Serial holder
			translate([USBserialX,USBserialY,BoxThk])
				doUSBserialHolder();
		}

		// Panel mounting holes
		translate([BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,0,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,0,BoxThk+BoxPanelSpacing+BoxPanelHgt-BoxPanelMntLen/2])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen-BoxPanelMntLen/2,0,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen-BoxPanelMntLen/2,0,BoxThk+BoxPanelSpacing+BoxPanelHgt-BoxPanelMntLen/2])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen/2,0,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([0,BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([0,BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,BoxThk+BoxPanelHgt-BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([0,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen-BoxPanelMntLen/2,BoxThk+BoxPanelHgt-BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([0,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen-BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([0,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxLen,BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxLen,BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,BoxThk+BoxPanelHgt-BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxLen,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen-BoxPanelMntLen/2,BoxThk+BoxPanelHgt-BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxLen,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen-BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxLen,BoxCornerLen+BoxPanelSpacing+BoxTopPanelLen/2-BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])  // Off center for fan clearance
			rotate([0,90,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,BoxWid,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxPanelMntLen/2,BoxWid,BoxThk+BoxPanelSpacing+BoxPanelHgt-BoxPanelMntLen/2])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen-BoxPanelMntLen/2,BoxWid,BoxThk+BoxPanelMntLen/2+BoxPanelSpacing])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);
		translate([BoxCornerLen+BoxPanelSpacing+BoxFrontPanelLen-BoxPanelMntLen/2,BoxWid,BoxThk+BoxPanelSpacing+BoxPanelHgt-BoxPanelMntLen/2])
			rotate([90,0,0])
				cylinder(d=Num2HoleDia,h=30,$fn=6,center=true);

		// Lid mounting holes
		translate([LidMntIn,LidMntIn,BoxHgt-15])
			cylinder(d=Num2HoleDia,h=20,$fn=6);
		translate([LidMntIn,BoxWid-LidMntIn,BoxHgt-15])
			cylinder(d=Num2HoleDia,h=20,$fn=6);
		translate([BoxLen-LidMntIn,LidMntIn,BoxHgt-15])
			cylinder(d=Num2HoleDia,h=20,$fn=6);
		translate([BoxLen-LidMntIn,BoxWid-LidMntIn,BoxHgt-15])
			cylinder(d=Num2HoleDia,h=20,$fn=6);

		//Bracket mounting holes
		translate([BracketMntIn,BracketToSide-TabScrewOut,.5])
			cylinder(d=Num2HoleDia,h=15,$fn=6);
		translate([BracketMntIn+BracketMntDist,BracketToSide-TabScrewOut,.5])
			cylinder(d=Num2HoleDia,h=15,$fn=6);

	}

	if (2 == Showing)
	{
		// USB-Serial adapter
		translate([USBserialX,USBserialY,BoxThk])
			doUSBserial();
	}
}

module doFoot(Side = 0)
{
	if (Side)
	{
		difference()
		{
			hull()
			{
				cube([FootLen,FootWid,2]);
				translate([0,FootWid-FootBaseWid,0])
					cube([FootBaseLen,FootBaseWid,FootHgt]);
			}

			// Screw hole
			translate([BoxPanelMntLen/2,FootWid-(BoxThk+BoxPanelMntLen/2),2.5])
				cylinder(d=6,h=FootHgt,$fn=8);
			translate([BoxPanelMntLen/2,FootWid-(BoxThk+BoxPanelMntLen/2),-1])
				cylinder(d=Num2ClearHoleDia,h=FootHgt,$fn=8);
		}
	}
	else
	{
		difference()
		{
			hull()
			{
				cube([FootLen,FootWid,2]);
				cube([FootBaseLen,FootBaseWid,FootHgt]);
			}

			// Screw hole
			translate([BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2,2.5])
				cylinder(d=6,h=FootHgt,$fn=8);
			translate([BoxPanelMntLen/2,BoxThk+BoxPanelMntLen/2,-1])
				cylinder(d=Num2ClearHoleDia,h=FootHgt,$fn=8);
		}
	}
}
module doSpeaker()
{
	color("Brown")
		cylinder(d=SpkDia,h=SpkHgt,$fn=72);
}

module doSpeakerLid()
{
	union()
	{
		translate([0,-SpkDia/2-1.5,0])
			difference()
			{
				cylinder(d=SpkDia+4,h=1,$fn=72);
				rotate([0,0,45])
					translate([SpkDia/2,0,0])
						cube([4,3,5],center=true);
			}
		translate([0,SpkDia/2+1.5,0])
			difference()
			{
				cylinder(d=SpkDia+4,h=1,$fn=72);
				rotate([0,0,-45])
					translate([SpkDia/2,0,0])
						cube([4,3,5],center=true);
			}
	}
}

module doSpeakerHoles()
{
	difference()
	{
		cylinder(d=SpkDia-2.5,h=6,$fn=72);
		for(x=[-16:4:16])
		{
			translate([x-.3,-20,-1])
				cube([.6,40,8]);
			translate([-20,x-.3,-1])
				cube([40,.6,8]);
		}
	}
}

module doCamMnts()
{
	translate([-12.5,-21/2,0])
		union()
		{
			for(x=[0:3])
				for(y=[0:3])
					translate([PiCamHolesY[x],PiCamHolesX[y],0])
						cylinder(d=PiCamMntDia,h=5.5);
		}
}

module doCamHoles()
{
	union()
	{
		translate([-12.5,-21/2,0])
			union()
			{
				for(x=[0:3])
					for(y=[0:3])
						translate([PiCamHolesY[x],PiCamHolesX[y],0])
							cylinder(d=Num1HoleDia,h=10);					
			}
			cylinder(d=CamHoleDia,h=20,center=true,$fn=72);
	}
}

module doUSBserialHolder()
{
	union()
	{
		translate([-22/2,-2.5,0])
			difference()
			{
				cube([22,USBserialConLen+2.5-BoxPanelThk,15]);
				translate([22/2-(12.3+1)/2,2,-.1])
					cube([12.3+1,USBserialConLen+3,16]);
				translate([1,-.1,8])
					cube([20,USBserialConLen-4.5,10]);
				translate([10,-.1,-.1])
					cube([15,3,17]);
			}
	}
}
	
module doUSBserialHole()
{
	translate([-(USBserialConWid+2)/2,0,0])
		cube([USBserialConWid+2,USBserialConHgt+2-BoxPanelSpacing,10]);
}
	
module doUSBserial()
{
	union()
	{
		color("Silver")
			translate([-USBserialConWid/2,0,0])
				cube([USBserialConWid,USBserialConLen,USBserialConHgt]);
		color("Green")
			translate([-18/2,9-38.4,USBserialConHgt])
				cube([18,38.4,10.7]);
	}
}
	
module doUSBsocket()
{
	color("Grey")
	{
		translate([0,USBsocketHoleSpacing/2,22])
			cube([USBsocketWid,USBsocketHgt,44],center=true);
		translate([0,USBsocketHoleSpacing/2,USBsocketBaseThk/2])
			cube([USBsocketWid,USBsocketBaseHgt,USBsocketBaseThk],center=true);
	}
}

module doUSBholes()
{
	union()
	{
		cylinder(d=M3ClearHole,h=15,center=true,$fn=12);
		translate([0,USBsocketHoleSpacing,0])
			cylinder(d=M3ClearHole,h=15,center=true,$fn=12);
		translate([0,USBsocketHoleSpacing/2,0])
			cube([USBsocketWid,USBsocketHgt,15],center=true);
	}
}

module doBackHoles()
{
	union()
	{
		translate([7.5,4.75,0])
			cylinder(d=AudioHoleDia,h=10,center=true,$fn=36);
		translate([29,5.75,0])
			cube([HDMIwid,HDMIhgt,10],center=true);
		translate([50.3,3,0])
			cube([USBwid,USBhgt,10],center=true);
		translate([-28,-1,1])  // Sink Pi into back a bit
			difference()
			{
				cube([92,20.5,10]);
				translate([32,HatExtHeadThk+PiHeadThk-.5,0])
					cube([60,2,10]);
			}
	}
}

module doBotFanHoles()
{
	union()
	{
		translate([-(FanWid+2)/2,-(FanWid+2)/2,0])
			cube([FanWid+2,FanWid+2,10]);
		difference()
		{
			cylinder(d=FanOpeningDia,h=10,$fn=72,center=true);
			for(x=[-16:4:16])
			{
				translate([x-.3,-20,-6])
					cube([.6,40,6]);
				translate([-20,x-.3,-6])
					cube([40,.6,6]);
			}
		}
	}
}

module doFanMountHoles(dia)
{
	union()
	{
		translate([FanFrontHoleInset,FanFrontHoleInset,-1])
			cylinder(d=dia,h=FanThk+2,$fn=36);
		translate([FanWid-FanFrontHoleInset,FanFrontHoleInset,-1])
			cylinder(d=dia,h=FanThk+2,$fn=36);
		translate([FanFrontHoleInset,FanWid-FanFrontHoleInset,-1])
			cylinder(d=dia,h=FanThk+2,$fn=36);
		translate([FanWid-FanFrontHoleInset,FanWid-FanFrontHoleInset,-1])
			cylinder(d=dia,h=FanThk+2,$fn=36);
	}
}

module doFanMnts()
{
	translate([-FanWid/2,-FanWid/2,0])
		union()
		{
			translate([FanFrontHoleInset,FanFrontHoleInset,0])
				difference()
				{
					cylinder(d=FanMntDia,h=FanThk-1,$fn=8); // Fan support
					cylinder(d=2,h=FanThk,$fn=8); // Screw hole
				}
			translate([FanWid-FanFrontHoleInset,FanFrontHoleInset,-1])
				difference()
				{
					cylinder(d=FanMntDia,h=FanThk-1,$fn=8); // Fan support
					cylinder(d=2,h=FanThk,$fn=8); // Screw hole
				}
			translate([FanFrontHoleInset,FanWid-FanFrontHoleInset,-1])
				difference()
				{
					cylinder(d=FanMntDia,h=FanThk-1,$fn=8); // Fan support
					cylinder(d=2,h=FanThk,$fn=8); // Screw hole
				}
			translate([FanWid-FanFrontHoleInset,FanWid-FanFrontHoleInset,-1])
				difference()
				{
					cylinder(d=FanMntDia,h=FanThk-1,$fn=8); // Fan support
					cylinder(d=2,h=FanThk,$fn=8); // Screw hole
				}
		}
}

module doFan()
{
	color("Black")
	{
		translate([-FanWid/2,-FanWid/2,0])
			difference()
			{
				cube([FanWid,FanWid,FanThk]);
				doFanMountHoles(FanHoleDia);
			}
	}
}

module doLED(doRed = 0)
{
	union()
	{
		color("Silver")
		{
			cylinder(d=LEDholeDia,h=LEDlen,$fn=36);
			translate([0,0,-LEDbezelHgt])
				difference()
				{
					cylinder(d=LEDbezelDia,h=LEDbezelHgt,$fn=36);
					cylinder(d=LEDdia,h=1.8*LEDbezelHgt,$fn=36,center=true);
				}
		}
		translate([0,0,1-LEDbezelHgt])
				if (doRed)
					color("Red")
						cylinder(d=LEDdia,h=LEDlen,$fn=36);
				else
					color("Green")
						cylinder(d=LEDdia,h=LEDlen,$fn=36);
	}
}

module doSwitch()
{
	union()
	{
		color("Black"){
			translate([0,0,SwitchHgt/2])
				cube([SwitchWid,SwitchWid,SwitchHgt],center=true);
			translate([0,0,SwitchHgt])
				cylinder(d=SwitchButtonDia,h=6,$fn=18);
		}
	}
}

module doEthernet()
{
	color("White")
		union()
		{
			translate([-16.25/2,-14.5/2,0])
				cube([16.25,14.5,10]);
			translate([-22/2,-16.25/2,10])
				cube([22,16.25,24]);
		}
}

// Routine to make a rounded cube
module RndCube(Wid,Hgt,Thk,RndDia = 3)
{
	difference()
	{
		cube([Wid,Hgt,Thk]);
		translate([Wid-RndDia,Hgt-RndDia,0])
			RndTool(RndDia,Thk);
		translate([RndDia,RndDia,0])
			rotate([0,0,180])
				RndTool(RndDia,Thk);
		translate([Wid-RndDia,RndDia,0])
			rotate([0,0,270])
				RndTool(RndDia,Thk);
		translate([RndDia,Hgt-RndDia,0])
			rotate([0,0,90])
				RndTool(RndDia,Thk);
	}
}

// Routine to make the tool for rounding a vertical corner
module RndTool(Rad, Thk)
{
	translate([0,0,-1])
		difference()
		{
			cube([2*Rad,2*Rad,Thk+2]);
			translate([0,0,-1])
				cylinder(Thk+4,Rad,Rad,$fn=90);
		}
}

