// File to draw an Adfruit 1.3" OLED display
// Also defines hole sizes/locations
// Draws display flat with the front left corner
// mounting hole of the board at 0,0,0.

// Overall display/board dimensions
OLEDwid = 1.38 * 25.4;
OLEDhgt = 35.5;
OLEDboardThk = 3;
OLEDdispThk = 1.5;
OLEDdispHgt = 25.4 * .9;
OLEDactThk = .5;
OLEDactHgt = 19;

// Disp location from top of board
OLEDdispY = 25.4 * (1.16-.9);

OLEDpinsIn = 7.4;  // Distance to pin headed from board side
OLEDpinsDown = .12*25.4;  // Distance to pin headed from board top

// Mounting hole locations
// Ref to the upper left corner of the board
OLEDholeX = [.12*25.4,.12*25.4,1.26*25.4,1.26*25.4];
OLEDholeY = [.12*25.4,1.28*25.4,.12*25.4,1.28*25.4];
OLEDholeDia = 3;
OLEDxSpacing = OLEDholeX[2] - OLEDholeX[1];
OLEDySpacing = OLEDholeY[1] - OLEDholeY[0];

Num2HoleDia = 2.5;		// #2 screw hole diameter

// doOLEDdisp();

// %doOLEDholes();

module doOLEDdisp()
{
	translate([-OLEDholeX[0],-OLEDholeY[0],0])
		union()
		{
			// Board
			difference()
			{
				// Board
				color("Green")
					translate([0,0,-OLEDboardThk])
						cube([OLEDwid,OLEDhgt,OLEDboardThk]);

				// Mounting holes
				for (x = [0:3])
					for (y = [0:3])
						translate([OLEDholeX[x],OLEDhgt-OLEDholeY[x],0])
							cylinder(d=OLEDholeDia,h=20,$fn=36,center=true);
			}

			// Display
			color("Black")
				translate([0,OLEDhgt-OLEDdispY-OLEDdispHgt,0])
					cube([OLEDwid,OLEDdispHgt,OLEDdispThk]);

			// Active display area
			color("White")
				translate([0,OLEDhgt-OLEDdispY-OLEDactHgt,OLEDdispThk])
					cube([OLEDwid,OLEDactHgt,OLEDactThk]);

			// Pins
			translate([OLEDpinsIn,OLEDhgt-OLEDpinsDown,0])
					for(x = [0:8])
						translate([2.54*x,0,-9])
							color("GOLD")
								cube([.635,.635,10.5]);
		}
}

module doOLEDholes()
{
	translate([-OLEDholeX[0],-OLEDholeY[0],0])
		union()
		{
			// Mounting holes
			for (x = [0:3])
				for (y = [0:3])
					translate([OLEDholeX[x],OLEDhgt-OLEDholeY[x],0])
						cylinder(d=Num2HoleDia,h=9,$fn=36,center=true);

			// Active display area
			translate([0,OLEDhgt-OLEDdispY-OLEDactHgt,0])
				cube([OLEDwid,OLEDactHgt,10]);

			// Display clearance hole
			translate([-1,OLEDhgt-OLEDdispY-OLEDdispHgt-1,-7.5])
				cube([OLEDwid+2,OLEDdispHgt+2,10]);

			// Header connector clearance hole
			translate([(OLEDwid-.9*25.4)/2,OLEDhgt-6,-7.5])
				cube([.9*25.4,6,10]);

			// Display flex clearance hole
			translate([(OLEDwid-24)/2,-3,-7.5])
				cube([24,9,10]);
		}
}
