// Open SCAD lib for drawing Raspberry Pi, and mounting studs
// Also can do Pi camera and a Pi hat board

// Raspberry Pi Board dimensions
PiLen = 85;
PiWid = 56;
PiThk = 1.4;
PiHeadThk = 2.5; // Height of base of header

// Raspberry Pi Mounting hole spacing
PiHoleSpaceX = 58;
PiHoleSpaceY = 49;

// Raspberry Pi hole locations, 0,0 is corner of board by USB power connector
PiHolesX = [3.5,PiHoleSpaceX+3.5,3.5,PiHoleSpaceX+3.5];
PiHolesY = [3.5,3.5,PiHoleSpaceY+3.5,PiHoleSpaceY+3.5];
PiMntDia = 5; // Mounting stud diameter

// PiHat stuff
PiHatLen = 65;
HatExtHeadThk = 13.5; // Depth of extended header below board

// Pi camera stuff
PiCamBrdWid = 25;
PiCamBrdHgt = 24;
PiCamBrdThk = .9;
PiCamWid = 8;
PiCamHgt = 5.4;

// Hole locations, 0,0 is upper left hole
PiCamHolesX = [0,21,0,21];
PiCamHolesY = [0,0,12.5,12.5];
PiCamMntDia = 5; // Mounting stud diameter

// Hole diameters
Num1HoleDia = 2.4; // #1 screw hole diameter
Num1ClearHoleDia = 3.2; // #1 screw clearance hole
Num2HoleDia = 2.6; // #2 screw hole diameter
Num2ClearHoleDia = 3.7; // #2 screw clearance hole


//doPi2();
//translate([0,0,-5])
//	doPiMounts(5);

// Draws Pi mounting studs Hgt mm tall with #2 screw holes
// Assumes (0,0) is corner of board near usb power connector
module doPiMounts(Hgt = 5)
{
	difference()
	{
		for (cnt = [0:3])
			translate([PiHolesX[cnt],PiHolesY[cnt],0])
				cylinder(Hgt,PiMntDia/2,PiMntDia/2,$fn=8);
		for (cnt = [0:3])
			translate([PiHolesX[cnt],PiHolesY[cnt],-1])
				cylinder(20,Num2HoleDia/2,Num2HoleDia/2,$fn=8);
	}

}

// Draws the Pi with the corner by the USB power jack at [0,0,0]
module doPi2()
{
	difference()
	{
		union()
		{
			color("GREEN")
				cube([PiLen,PiWid,PiThk]);  // Board
			translate([65.5,10.25-16/2,PiThk])  // Ethernet
				color("SILVER")
					cube([21.25,16,13.5]);
			translate([69.7,29-13.1/2,PiThk])  // USB
				color("SILVER")
					cube([17,13.1,15.8]);
			translate([69.7,47-13.1/2,PiThk])  // USB
				color("SILVER")
					cube([17,13.1,15.8]);
			translate([32-15.2/2,-1.45,PiThk])  // HDMI
				color("SILVER")
					cube([15.2,11.9,7]);
			translate([10.6-7.5/2,-1.6,PiThk])  // USB power
				color("SILVER")
					cube([7.5,5.7,3]);
			translate([53.5-6.9/2,-2.15,PiThk])  // Audio jack
				color("BLACK")
					cube([6.9,14.5,6.5]);
			translate([-3,PiWid/2-11/2,-1.2])  // Micro SD Card
				color("BLACK")
					cube([15,11,1.2]);
			translate([29+3.5-50.7/2,50,PiThk])  // 40 pin header
				union()
				{
					color("BLACK")
						cube([50.7,5.1,PiHeadThk]);
					translate([(50.7-2.54*19-.635)/2,(5.1-2.54-.635)/2,0])
						for(x = [0:19])
							for(y = [0:1])
								translate([2.54*x,2.54*y,0])
								color("GOLD")
									cube([.635,.635,9]);
				}
		}
		// Raspberry Pi mounting holes
		for (cnt = [0:3])
			translate([PiHolesX[cnt],PiHolesY[cnt],-1])
				cylinder(20,d=2.75,$fn=16);
	}
}

// Draws the Pi Hat with the corner by the USB power jack at [0,0,0]
module doPiHat()
{
	difference()
	{
		union()
		{
			color("White")
				cube([PiHatLen,PiWid,PiThk]);  // Board
			translate([29+3.5-50.7/2,50,PiThk])  // 40 pin header
				union()
				{
					translate([0,0,-HatExtHeadThk-PiThk])
						color("BLACK")
							cube([50.7,5.1,HatExtHeadThk]);
					translate([(50.7-2.54*19-.635)/2,(5.1-2.54-.635)/2,0])
						for(x = [0:19])
							for(y = [0:1])
								translate([2.54*x,2.54*y,0])
								color("GOLD")
									cube([.635,.635,9]);
				}
		}
		// Raspberry Pi mounting holes
		for (cnt = [0:3])
			translate([PiHolesX[cnt],PiHolesY[cnt],-1])
				cylinder(20,d=2.75,$fn=16);
	}
}

// Draw the Pi camera
module doPiCamera()
{
}
