// Brackets to hold Raspbery Pi and WD Pi drive
// Print at .3 Layer height with 2 extra shells and 15% infill

include <pi.scad>
include <drives.scad>


// Figure distance between drive and Pi mounting holes
HoleOffset = ((HD2_HoleX2-HD2_HoleX1)-(PiHolesX[1]-PiHolesX[0]))/2;

PiMntHgt = 4;
PiMntWid = 7;
PiMntInset = -10;
Num2HoleDia = 2.5;		// #2 screw hole diameter
Num2ClearHoleDia = 3.7; // #2 screw clearance hole

DriveMntHgt = 6;
DriveClearance = 10;
DriveMntHoleDia = 4;
DriveMntHoleInset = 4;
DriveWidFudge = 1; // Fudge for clearance on bracket

// Bracket dimensions
BracketThk = 3;
BracketWid = HoleOffset + PiMntWid / 2 + DriveMntHoleInset;
BracketHgt = DriveMntHgt + DriveClearance;
BracketLen = HD2_5Wid + 2 * BracketThk + DriveWidFudge;
BracketTabLen = 9;
BracketTabWid = 7;
BracketTabHgt = 5;
TabScrewOut = 4.5;  // Distance from edge of bracket side to screw
TabScrewIn = BracketTabWid / 2;  // Distance in from edge of tab to screw
SideMntThk = 10;
SideMntWid = 7;

/*
doBracket(0);
translate([30,0,0])
	doBracket(1);
*/

module doBracket(Which = 0)
{
	difference()
	{
		union()
		{
			// Bracket sections
			translate([BracketHgt-BracketThk,0,0])
				cube([BracketThk,BracketLen,BracketWid]);
			cube([BracketHgt,BracketThk,BracketWid]);
			translate([0,BracketLen-BracketThk,0])
				cube([BracketHgt,BracketThk,BracketWid]);
			if (Which)
			{
				translate([BracketTabHgt,BracketLen,0])
					cube([BracketThk,BracketTabLen,BracketTabWid]);
				translate([0,-SideMntThk,0])
					cube([BracketHgt,SideMntThk,SideMntWid]);
			}
			else
			{
				translate([BracketTabHgt,-BracketTabLen,0])
					cube([BracketThk,BracketTabLen,BracketTabWid]);
				translate([0,BracketLen,0])
					cube([BracketHgt,SideMntThk,SideMntWid]);
			}

			// Pi mounts
			if (Which)
			{
				translate([BracketHgt,PiMntInset,0])
					cube([PiMntHgt,PiMntWid,PiMntWid]);
				translate([BracketHgt,PiHolesY[2]-PiHolesY[1]+PiMntInset,0])
					cube([PiMntHgt,PiMntWid,PiMntWid]);
			}
			else
			{
				translate([BracketHgt,BracketLen-PiMntWid-PiMntInset,0])
					cube([PiMntHgt,PiMntWid,PiMntWid]);
				translate([BracketHgt,BracketLen-PiMntWid-(PiHolesY[2]-PiHolesY[1])-PiMntInset,0])
					cube([PiMntHgt,PiMntWid,PiMntWid]);
			}
		}

		// Drive mounting holes
		translate([DriveMntHgt,0,BracketWid-DriveMntHoleInset])
			rotate([90,0,0])
				cylinder(d=DriveMntHoleDia,h=10,center=true,$fn=12);
		translate([DriveMntHgt,BracketLen,BracketWid-DriveMntHoleInset])
			rotate([90,0,0])
				cylinder(d=DriveMntHoleDia,h=10,center=true,$fn=12);

		// Bracket tab holes
		if (Which)
			translate([BracketTabHgt,BracketLen+TabScrewOut,TabScrewIn])
				rotate([0,90,0])
					cylinder(d=Num2ClearHoleDia,h=10,center=true,$fn=10);
		else
			translate([BracketTabHgt,-TabScrewOut,TabScrewIn])
				rotate([0,90,0])
					cylinder(d=Num2ClearHoleDia,h=10,center=true,$fn=10);

		// Side mount holes
		if (Which)
			translate([BracketHgt/2,-TabScrewOut,SideMntWid/2])
				rotate([90,0,0])
					cylinder(d=Num2HoleDia,h=20,center=true,$fn=6);
		else
			translate([BracketHgt/2,BracketLen+TabScrewOut,SideMntWid/2])
				rotate([90,0,0])
					cylinder(d=Num2HoleDia,h=20,center=true,$fn=6);

		// Pi mounting holes
		if (Which)
		{
			translate([BracketHgt-BracketThk+4.9,PiMntWid/2+PiMntInset,PiMntWid/2])
				rotate([0,90,0])
					cylinder(d=Num2HoleDia,h=10,$fn=6,center=true);
			translate([BracketHgt-BracketThk+4.9,PiHolesY[2]-PiHolesY[1]+PiMntWid/2+PiMntInset,PiMntWid/2])
				rotate([0,90,0])
					cylinder(d=Num2HoleDia,h=10,$fn=6,center=true);
		}
		else
		{
			translate([BracketHgt-BracketThk+4.9,BracketLen-PiMntWid+PiMntWid/2-PiMntInset,PiMntWid/2])
				rotate([0,90,0])
					cylinder(d=Num2HoleDia,h=10,$fn=6,center=true);
			translate([BracketHgt-BracketThk+4.9,BracketLen-PiMntWid-(PiHolesY[2]-PiHolesY[1])+PiMntWid/2-PiMntInset,PiMntWid/2])
				rotate([0,90,0])
					cylinder(d=Num2HoleDia,h=10,$fn=6,center=true);
		}
	}
}
