// Case for Raspbery Pi and WD Pi drive
// Print all except logo at .3 Layer height with 2 extra shells and 15% infill
// Print logo at .2 layer height with 1 extra shell and 20% infil

include <pi.scad>
include <drives.scad>
include <PiBracket.scad>
include <OLED.scad>
include <Box.scad>

Show = 2;  // Set to 0 to print parts, 1 to show assembly, 2 to show everything
ShowSide = 1; // Set 2222true to show the side panel when Show != 0
ShowFeet = 1; // Set true to show the feet when Show != 0
Print = 12;
// 1-Brackets, 2-Box base, 3-Top panel 
// 4 - Front panel, 5 - Back panel, 6 - Bottom panel
// 7 - Box side, 8 - Speaker lid, 9 - Feet, 10 - Window frame
// 11 - Logo panel, 12 - Logo panel centering jig

BracketToSide = BoxWid-BoxPanelThk-BoxPanelInset-BracketLen-SideMntThk;
BracketToFront = BracketWid-DriveMntHoleInset-TabScrewIn;

	if (Show)
	{
		translate([0,0,BoxLen])
			rotate([0,90,0])
				DrawPUC();
// Ckeck cable clearance
//translate([20,60,120])cube([20,20,58]);
	}
	else
	{
		if (1 == Print)  // Brackets
		{
			doBracket(0);
			translate([30,0,0])
				doBracket(1);
		}
		else if (2 == Print)  // Box bottom
		{
			doBoxBase(0);
		}
		else if (3 == Print)  // Box top
		{
			doBoxTopPanel(0);
		}
		else if (4 == Print)  // Front panel
		{
			doBoxFrontPanel(0);
		}
		else if (5 == Print)  // Back panel
		{
			doBoxBackPanel(0);
		}
		else if (6 == Print)  // Lid
		{
			doBoxBottomPanel(0,1,ShowFeet);
		}
		else if (7 == Print)  // Lid
		{
			doBoxSide();
		}
		else if (8 == Print)  // Speaker lid
		{
			doSpeakerLid();
		}
		else if (9 == Print)  // Feet
		{
			doFoot(0);
			translate([25,0,0])
				doFoot(0);
			translate([25,25,0])
				doFoot(1);
			translate([0,25,0])
				doFoot(1);
		}
		else if (10 == Print)  // Window frame
		{
			doWindowFrame();
		}
		else if (11 == Print)  // Logo panel
		{
			doLogo();
		}
		else if (12 == Print)  // Logo panel
		{
			doLogoJig();
		}
	}

module DrawPUC()
{
	translate([BracketMntIn-BracketToFront,BracketToSide,BoxThk])
	{
		translate([BracketWid-DriveMntHoleInset,0,0])
			rotate([0,-90,0])
				doBracket(0);
		translate([DriveMntHoleInset-BracketWid+(HD2_HoleX2-HD2_HoleX1),BracketLen,0])
			rotate([0,-90,180])
				doBracket(1);

		if (2 == Show)
		{
			translate([PiHolesX[0]+HoleOffset+(PiHolesX[1]-PiHolesX[0])
						,PiWid-PiHolesX[0]+BracketLen-PiMntInset-PiMntWid/2-(PiHolesY[2]-PiHolesY[1])
						,BracketHgt+PiMntHgt])
				rotate([0,0,180])
					doPi2();

				translate([PiHolesX[0]+HoleOffset+(PiHolesX[1]-PiHolesX[0])
						,PiWid-PiHolesX[0]+BracketLen-PiMntInset-PiMntWid/2-(PiHolesY[2]-PiHolesY[1])
						,BracketHgt+PiMntHgt+HatExtHeadThk+PiHeadThk+PiThk])
				rotate([0,0,180])
					doPiHat();
	// Ckeck Pi hat clearance
	//translate([35,70,BracketHgt+PiMntHgt])cube([20,20,42]);

			translate([-HD2_HoleX1,BracketThk+DriveWidFudge/2,DriveMntHgt-HD2_5SideHoleUp])
				doHD2_5();
		}
	}

			doBoxBase(Show,1);

//translate([0,0,120])  // Check frame fit
		if (ShowSide)
		{
			translate([0,BoxWid,BoxHgt+BoxThk])
				rotate([-180,0,0])
					doBoxSide(1);
			translate([0,0,-WindowLipThk])
					doLogo();
		}

		// Do box panels
		translate([BoxCornerLen+BoxPanelSpacing,BoxPanelInset,BoxThk+BoxPanelSpacing])
			rotate([-90,0,0])
				translate([0,-BoxPanelHgt,0])
					doBoxFrontPanel(Show);

		translate([BoxCornerLen+BoxPanelSpacing,BoxWid-BoxPanelInset,BoxThk+BoxPanelSpacing])
			rotate([90,0,0])
				doBoxBackPanel(Show);

		translate([BoxPanelInset,BoxCornerLen+BoxPanelSpacing,BoxThk+BoxPanelSpacing])
			rotate([90,0,90])
				doBoxTopPanel(Show);

		translate([BoxLen,BoxCornerLen+BoxPanelSpacing,BoxThk+BoxPanelSpacing+BoxPanelHgt])
			rotate([-90,0,90])
				doBoxBottomPanel(Show,1,ShowFeet);
}